@@ -218,7 +218,7 @@ on_window1_size_allocate               (GtkWidget       *widget,
                                         GtkAllocation   *allocation,
                                         gpointer         user_data)
 {
-/*	printf ("SizeA x = %d, y = %d, width = %d, height = %d\n", allocation->x, allocation->y, allocation->width, allocation->height); */
+        gok_log ("SizeA x = %d, y = %d, width = %d, height = %d\n", allocation->x, allocation->y, allocation->width, allocation->height); 
 	gok_keyboard_on_window_resize ();
 }
 
@@ -902,8 +902,8 @@ on_joystick_button_toggled             (GtkToggleButton *togglebutton,
                                         gpointer         user_data)
 {
 	gok_page_actions_set_is_corepointer (
-		!gtk_toggle_button_get_active (togglebutton));
-}
+		!gtk_toggle_button_get_active (togglebutton));}
+
 
 void
 on_checkExtraWordList_toggled          (GtkToggleButton *togglebutton,
