@@ -253,6 +253,8 @@ gboolean gok_key_make_html_safe (gchar* pString, gchar* pSafeString, gint SafeSt
 gboolean gok_key_contains_point (GokKey *pKey, gint x, gint y);
 void gok_key_set_effective_group (gint group);
 gint gok_key_get_effective_group (void);
+int gok_key_get_xkb_type_index (XkbDescPtr xkb, KeyCode keycode, guint group);
+int gok_key_level_for_type (Display *display, XkbDescRec *kbd, int type, unsigned int *modmask);
 GokKeyImage* gok_keyimage_new (GokKey *pKey, gchar* Filename);
 void gok_keyimage_delete (GokKeyImage* pKeyImage);
 gboolean gok_key_isRepeatable(GokKey* pKey);
